@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.808.2.5 2020/05/18 00:11:08 jca Exp $
+# $OpenBSD: Quirks.pm,v 1.953 2020/05/08 16:44:41 landry Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -62,7 +62,7 @@ my $base_exceptions = {
 # 5.7
 	'p5-IO-Socket-IP' => "$p5/IO/Socket/IP.pm",
 # 5.8
-	'libepoxy' => '/usr/X11R6/lib/libepoxy.so.1.0',
+	'libepoxy' => '/usr/X11R6/lib/libepoxy.so.*',
 	'flex' => '/usr/bin/flex',
 # 6.0
 	'p5-Term-ReadKey' => "$p5a/Term/ReadKey.pm",
@@ -70,7 +70,7 @@ my $base_exceptions = {
 	'p5-Test-use-ok' => "$p5/Test/use/ok.pm",
 	'p5-Test-Tester' => "$p5/Test/Tester.pm",
 # 6.5
-	'libelf' => '/usr/lib/libelf.so.2.0',
+	'libelf' => '/usr/lib/libelf.so.*',
 };
 
 my $stem_extensions = {
@@ -336,6 +336,89 @@ my $stem_extensions = {
 	'bro' => 'zeek',
 	'filter-rspamd' => 'opensmtpd-filter-rspamd',
 	'filter-senderscore' => 'opensmtpd-filter-senderscore',
+	'ilmbase' => 'OpenEXR',
+	'openexr-viewers' => 'OpenEXR-tools',
+	'libvirt-python' => 'py-libvirt',
+# 6.7
+	'py-jaraco-functoolsjaraco.functools' => 'py-jaraco-functools',
+	'py3-jaraco-functoolsjaraco.functools' => 'py3-jaraco-functools',
+	'py3-qscintilla-qt5' => 'py3-qscintilla',
+	'py-netmiko' => 'py3-netmiko',
+	'py-napalm' => 'py3-napalm',
+	'py-IOSXR' => 'py3-IOSXR',
+	'py-cligj' => 'py3-cligj',
+	'py-fiona' => 'py3-fiona',
+	'py-laspy' => 'py3-laspy',
+	'py-owslib' => 'py3-owslib',
+	'py-proj' => 'py3-proj',
+	'py-planet' => 'py3-planet',
+	'py-rasterio' => 'py3-rasterio',
+	'py-rio-cogeo' => 'py3-rio-cogeo',
+	'py-shapely' => 'py3-shapely',
+	'py-terminado' => 'py3-terminado',
+	'py-prometheus_client' => 'py3-prometheus_client',
+	'py-influxdb' => 'py3-influxdb',
+	'py-pandas' => 'py3-pandas',
+	'py-siphon' => 'py3-siphon',
+	'py-mlpack' => 'py3-mlpack',
+	'py-bottleneck' => 'py3-bottleneck',
+	'py-daemon' => 'py3-daemon',
+	'py-nbval' => 'py3-nbval',
+	'py-oauthlib' => 'py3-oauthlib',
+	'py-requests-oauthlib' => 'py3-requests-oauthlib',
+	'py-discogs-client' => 'py3-discogs-client',
+	'py-semver' => 'py3-semver',
+	'py-seaborn' => 'py3-seaborn',
+	'py-natsort' => 'py3-natsort',
+	'py-mastodon.py' => 'py3-mastodon.py',
+	'py-bokeh' => 'py3-bokeh',
+	'py-algorithm-munkres' => 'py3-algorithm-munkres',
+	'py-pdfminer' => 'py3-pdfminer',
+	'jupyter-notebook3' => 'jupyter-notebook',
+	'py-html2text' => 'py3-html2text',
+	'py-acme' => 'py3-acme',
+	'py-josepy' => 'py3-josepy',
+	'py-spyder-kernels' => 'py3-spyder-kernels',
+	'spyder' => 'spyder3',
+	'py-qtconsole' => 'py3-qtconsole',
+	'py-sympy' => 'py3-sympy',
+	'py-wurlitzer' => 'py3-wurlitzer',
+	'py-gunicorn' => 'py3-gunicorn',
+	'py-multidict' => 'py3-multidict',
+	'py-elasticsearch' => 'py3-elasticsearch',
+	'py-vmomi' => 'py3-vmomi',
+	'py-nbconvert' => 'py3-nbconvert',
+	'py-smbc' => 'py3-smbc',
+	'py-git2' => 'py3-git2',
+	'py-bencode' => 'py3-bencode',
+	'py-dfwinreg' => 'py3-dfwinreg',
+	'py-dfvfs' => 'py3-dfvfs',
+	'py-dfdatetime' => 'py3-dfdatetime',
+	'py-artifacts' => 'py3-artifacts',
+	'py-rope' => 'py3-rope',
+	'py-xlrd' => 'py3-xlrd',
+	'ipython' => 'ipython3',
+	'py-ipykernel' => 'py3-ipykernel',
+	'py-jupyter_client' => 'py3-jupyter_client',
+	'py-jupyter_core' => 'py3-jupyter_core',
+	'py-nbformat' => 'py3-nbformat',
+	'py-traitlets' => 'py3-traitlets',
+	'py-parso' => 'py3-parso',
+	'py-jedi' => 'py3-jedi',
+	'py-botocore' => 'py3-botocore',
+	'py-boto3' => 'py3-boto3',
+	'py-s3transfer' => 'py3-s3transfer',
+	'py-libpst' => 'py3-libpst',
+	'Clementine' => 'clementine',
+	'py-curtsies' => 'py3-curtsies',
+	'bpython3' => 'bpython',
+	'py-prompt_toolkit' => 'py3-prompt_toolkit',
+	'py-wcwidth' => 'py3-wcwidth',
+	'py-twitter' => 'py3-twitter',
+	'py-irclib' => 'py3-irclib',
+	'py-casttube' => 'py3-casttube',
+	'py-libcloud' => 'py3-libcloud',
+	'gegl03' => 'gegl04',
 };
 
 my $obsolete_reason = {
@@ -812,7 +895,6 @@ my $obsolete_reason = {
 	'letskencrypt' => 4,
 	'emiclock' => 0,
 	'rygel' => 8,
-	'vino' => 8,
 	'ttcp' => 0,
 	'aget' => 3,
 	'xfprint' => 3,
@@ -1310,12 +1392,171 @@ my $obsolete_reason = {
 	'arm-elf-gcc' => 6,
 	'arm-elf-gdb' => 6,
 	'arm-elf-newlib' => 6,
-	'py-mastodon.py' => 14,
 	'g77' => 5,
 	'libf2c' => 5,
 	'p5-WWW-Curl' => 3,
 	'java-tanukiwraper' => 5,
 	'opencv-docs' => 6,
+	'p5-Device-USB' => 6,
+	'p5-Crypt-GpgME' => 0,
+	'p5-HTTP-BrowserDetect' => 6,
+# 6.7
+	'awless' => 3,
+	'mousetweaks' => 3,
+	'py-ioflo' => 6,
+	'py3-ioflo' => 6,
+	'postgresql-plv8' => 5,
+	'py-GeoIP' => 6,
+	'cvsync' => 3,
+	'pecl-geoip' => 6,
+	'clive' => 5,
+	'aws-shell' => 6,
+	'aqsis' => 5,
+	'gtk-xfce-engine' => 3,
+	'firewalk' => 0,
+	'goffice08' => 5,
+	'terraform-provider-terraform' => 3,
+	'py-webdav' => 3,
+	'yabause' => 6,
+	'terraform-provider-softlayer' => 3,
+	'py-elementtidy' => 5,
+	'py-gd' => 5,
+	'py-oauth2' => 5,
+	'afm' => 6,
+	'p5-Geo-IP' => 6,
+	'py-libnacl' => 3,
+	'py3-typing' => 5,
+	'p5-Net-IRC' => 3,
+	'pangox-compat' => 0,
+	'qtserialport' => 5,
+	'tmake' => 5,
+	'qt3-sqlite3' => 5,
+	'eigen' => 5,
+	'eigen2' => 5,
+	'qt-gstreamer' => 5,
+	'qsynergy' => 3,
+	'kqoauth' => 5,
+	'valknut' => 3,
+	'dclib' => 3,
+	'luma' => 3,
+	'qhacc' => 15,
+	'nginx-geoip' => 17,
+	'qgo' => 16,
+	'qrfcview' => 3,
+	'mutella' => 3,
+	'erl-bcrypt' => 5,
+	'erl-mochiweb' => 5,
+	'rebar18' => 5,
+	'rebar17' => 5,
+	'bouml' => 3,
+	'beediff' => 18,
+	'php-mcrypt' => 3,
+	'sqliteman' => 19,
+	'entomologist' => 3,
+	'fcitx-qt4' => 6,
+	'partiwm' => 3,
+	'ejabberd' => 2,
+	'rebar16' => 5,
+	'tortoisehg' => 5,
+	'cjc' => 3,
+	'spectrum' => 3,
+	'py-xmpp' => 3,
+	'mirage' => 0,
+	'rpm' => 0,
+	'oggconvert' => 3,
+	'radiotray' => 3,
+	'xevil' => 0,
+	'py-vatnumber' => 3,
+	'nap' => 6,
+	'qucs' => 5,
+	'py-arrow' => 1,
+	'py3-arrow' => 1,
+	'py-chai' => 1,
+	'py3-chai' => 1,
+	'py-binaryornot' => 1,
+	'py3-binaryornot' => 1,
+	'py-whichcraft' => 1,
+	'py3-whichcraft' => 1,
+	'celt07' => 20,
+	'terraform-provider-alicloud' => 1,
+	'terraform-provider-archive' => 1,
+	'terraform-provider-arukas' => 1,
+	'terraform-provider-atlas' => 1,
+	'terraform-provider-aws' => 1,
+	'terraform-provider-azure' => 1,
+	'terraform-provider-azurerm' => 1,
+	'terraform-provider-bitbucket' => 1,
+	'terraform-provider-chef' => 1,
+	'terraform-provider-circonus' => 1,
+	'terraform-provider-clc' => 1,
+	'terraform-provider-cloudflare' => 1,
+	'terraform-provider-cloudstack' => 1,
+	'terraform-provider-cobbler' => 1,
+	'terraform-provider-consul' => 1,
+	'terraform-provider-datadog' => 1,
+	'terraform-provider-digitalocean' => 1,
+	'terraform-provider-dme' => 1,
+	'terraform-provider-dns' => 1,
+	'terraform-provider-dnsimple' => 1,
+	'terraform-provider-docker' => 1,
+	'terraform-provider-dyn' => 1,
+	'terraform-provider-exoscale' => 1,
+	'terraform-provider-external' => 1,
+	'terraform-provider-fastly' => 1,
+	'terraform-provider-github' => 1,
+	'terraform-provider-gitlab' => 1,
+	'terraform-provider-google' => 1,
+	'terraform-provider-grafana' => 1,
+	'terraform-provider-heroku' => 1,
+	'terraform-provider-http' => 1,
+	'terraform-provider-icinga2' => 1,
+	'terraform-provider-ignition' => 1,
+	'terraform-provider-influxdb' => 1,
+	'terraform-provider-kubernetes' => 1,
+	'terraform-provider-librato' => 1,
+	'terraform-provider-local' => 1,
+	'terraform-provider-logentries' => 1,
+	'terraform-provider-mailgun' => 1,
+	'terraform-provider-mysql' => 1,
+	'terraform-provider-newrelic' => 1,
+	'terraform-provider-nomad' => 1,
+	'terraform-provider-ns1' => 1,
+	'terraform-provider-null' => 1,
+	'terraform-provider-oneandone' => 1,
+	'terraform-provider-opc' => 1,
+	'terraform-provider-openstack' => 1,
+	'terraform-provider-opsgenie' => 1,
+	'terraform-provider-ovh' => 1,
+	'terraform-provider-packet' => 1,
+	'terraform-provider-pagerduty' => 1,
+	'terraform-provider-postgresql' => 1,
+	'terraform-provider-powerdns' => 1,
+	'terraform-provider-profitbricks' => 1,
+	'terraform-provider-rabbitmq' => 1,
+	'terraform-provider-rancher' => 1,
+	'terraform-provider-random' => 1,
+	'terraform-provider-rundeck' => 1,
+	'terraform-provider-scaleway' => 1,
+	'terraform-provider-spotinst' => 1,
+	'terraform-provider-statuscake' => 1,
+	'terraform-provider-template' => 1,
+	'terraform-provider-tls' => 1,
+	'terraform-provider-triton' => 1,
+	'terraform-provider-ultradns' => 1,
+	'terraform-provider-vault' => 1,
+	'terraform-provider-vcd' => 1,
+	'terraform-provider-vsphere' => 1,
+	'radare2-bindings' => 6,
+	'py3-django' => 1,
+	'py3-django-lts' => 1,
+	'dspam' => 3,
+	'dspam-mysql' => 3,
+	'dspam-pgsql' => 3,
+	'py-iniparse' => 5,
+	'qt5-declarative-xmllistmodel' => 3,
+	'jabberd' => 3,
+	'GeoIP' => 22,
+	'akpop3d' => 2,
 };
 
 # reasons for obsolete packages
@@ -1335,6 +1576,14 @@ my @msg = (
 	"replace with IMAPSieve, see https://wiki.dovecot.org/HowTo/AntispamWithSieve", #12
 	"has a dependency on obsolete software", #13
 	"python2 port superseded by python3 version", #14
+	"no longer maintained upstream, suggest homebank, gnucash, kmymoney", #15
+	"no longer maintained upstream, suggest kigo", #16
+	"old GeoIP databases end-of-life, see alternative using geoip2/libmaxminddb", #17
+	"no longer maintained upstream, suggest kompare", #18
+	"no longer maintained upstream, suggest sqlitebrowser, kexi", #19
+	"merged into IETF Opus codec, obsolete, audio/mumble uses bundled version now", #20
+	"upstream recommends to use composer to build a drupal site", #21
+	"the original GeoIP database is end of life; use libmaxminddb/GeoIP2", #22
 );
 
 # ->is_base_system($handle, $state):
@@ -1359,7 +1608,8 @@ sub is_base_system
 
 	my $test = $base_exceptions->{$stem};
 	if (defined $test) {
-		if (-e $test) {
+		require File::Glob;
+		if (defined File::Glob::bsd_glob($test)) {
 			$state->say("Removing #1 #2", $handle->pkgname,
 			    " (part of base system now)");
 			return 1;
@@ -1385,7 +1635,8 @@ sub filter_obsolete
 	for my $pkgname (@in) {
 		my $stem = OpenBSD::PackageName::splitstem($pkgname);
 		my $reason = $obsolete_reason->{$stem};
-		$reason = 3 if (!defined $reason && $pkgname =~ m/^(drupal(-6|6-)|ruby(19|2[0-3])-|ruby-[^0-9])/);
+		$reason = 3 if (!defined $reason && $pkgname =~ m/^(ruby(19|2[0-4])-|ruby-[^0-9])/);
+		$reason = 21 if (!defined $reason && $pkgname =~ m/^drupal/);
 		if (defined $reason) {
 			$state->say("Obsolete package: #1 (#2)", $pkgname, 
 			    $msg[$reason]);
@@ -1427,14 +1678,14 @@ my $cve = {
 	'archivers/libmspack' => 'libmspack-<0.8alpha',
 	'archivers/p5-Archive-Zip' => 'p5-Archive-Zip-<1.64',
 	'audio/flac' => 'flac-<1.3.0p1',
-	'databases/sqlite3' => 'sqlite3-<3.25.3',
-	'databases/mariadb,-main' => 'mariadb-client-<10.3.15',
+	'databases/mariadb,-main' => 'mariadb-client-<10.3.22',
 	'databases/mariadb,-server' => 'mariadb-server-<10.3.15',
 	'databases/postgresql,-main' => 'postgresql-client-<10.6',
 	'databases/postgresql,-server' => 'postgresql-server-<10.6',
-	'devel/git,-main' => 'git-<2.19.1',
-	'devel/git,-svn' => 'git-svn-<2.19.1',
-	'devel/git,-x11' => 'git-x11-<2.19.1',
+	'databases/sqlite3' => 'sqlite3-<3.25.3',
+	'devel/git,-main' => 'git-<2.26.2',
+	'devel/git,-svn' => 'git-svn-<2.26.2',
+	'devel/git,-x11' => 'git-x11-<2.26.2',
 	'devel/jenkins/devel' => 'jenkins-<2.154',
 	'devel/jenkins/stable' => 'jenkins-<2.138.4',
 	'devel/libgit2/libgit2' => 'libgit2-<0.27.7',
@@ -1455,13 +1706,14 @@ my $cve = {
 	'lang/ruby/2.6,-main' => 'ruby->2.6,<2.6.2',
 	'mail/dovecot,-main' => 'dovecot-<2.3.6',
 	'mail/exim' => 'exim-<4.83',
-	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.2',
+	'mail/mailman' => 'mailman-<2.1.30',
+	'mail/p5-Mail-SpamAssassin' => 'p5-Mail-SpamAssassin-<3.4.4',
 	'mail/roundcubemail' => 'roundcubemail-<1.3.8',
 	'math/hdf5' => 'hdf5-<1.8.21',
 	'multimedia/libquicktime' => 'libquicktime-<1.2.4p13',
 	'net/curl' => 'curl-<7.65.0',
 	'net/dhcpcd' => 'dhcpcd-<7.2.2',
-	'net/haproxy' => 'haproxy-<1.8.17',
+	'net/haproxy' => 'haproxy-<2.0.14',
 	'net/icecast' => 'icecast-<2.4.4',
 	'net/irssi' => 'irssi-<1.2.1',
 	'net/isc-bind' => 'isc-bind-<9.11.5pl4v0',
@@ -1469,12 +1721,13 @@ my $cve = {
 	'net/lldpd' => 'lldpd-<0.7.18p0',
 	'net/mosquitto' => 'mosquitto-<1.5.6',
 	'net/ntp' => 'ntp-<4.2.8pl7',
-	'net/openvpn' => 'openvpn-<2.4.7p2',
 	'net/openconnect' => 'openconnect-<8.05',
+	'net/openvpn' => 'openvpn-<2.4.9',
 	'net/powerdns,-main' => 'powerdns-<4.1.5',
 	'net/powerdns,-mysql' => 'powerdns-mysql-<4.1.5',
 	'net/powerdns,-pgsql' => 'powerdns-pgsql-<4.1.5',
-	'net/samba,-main' => 'samba-<4.8.4',
+	'net/rsync' => 'rsync-<3.1.3p0',
+	'net/samba,-main' => 'samba-<4.8.18',
 	'net/tinc' => 'tinc-<1.0.35v0',
 	'net/transmission,-gtk' => 'transmission-gtk-<2.84',
 	'net/transmission,-main' => 'transmission-<2.84',
@@ -1486,10 +1739,15 @@ my $cve = {
 	'net/znc' => 'znc-<1.7.3',
 	'print/cups,-main' => 'cups-<1.7.4',
 	'security/clamav' => 'clamav-<0.100.2',
+	'security/libssh' => 'libssh-<0.9.4',
+	'security/opensc' => 'opensc-<0.20.0',
+	'security/openssl/1.1' => 'openssl-<1.1.1g',
 	'security/polarssl' => 'mbedtls-<2.16.6',
+	'security/sudo' => 'sudo-<1.8.31',
 	'shells/bash' => 'bash-<4.3.27',
 	'sysutils/ansible,-main' => 'ansible-<2.7.1',
 	'sysutils/mcollective' => 'mcollective-<2.5.3',
+	'sysutils/salt' => 'salt-<2018.3.3p2',
 	'telephony/asterisk,-main' => 'asterisk-<13.23.1',
 	'telephony/coturn' => 'turnserver-<4.5.1.1',
 	'www/apache-httpd,-main' => 'apache-httpd-<2.4.35',
